@@ -97,7 +97,8 @@ class Recipe:
         for line in old_config:
             processed = False
             for k,v in values.items():
-                if line.startswith(k):
+                if line.startswith(k) \
+                   or line.startswith('# ' + k):
                     # replace old value with new one
                     config.write('%s=%s\n' % (k,v))
                     processed = True
